"""
    get_features_griffiths2011indian()

Generate the same features for the synthesised dataset used in (Griffiths and Ghahramani, 2011).

Ref: http://www.jmlr.org/papers/v12/griffiths11a.html
"""
function get_features_griffiths2011indian()
    features = []

    push!(features, vec(Int[0 1 0 0 0 0;
                            1 1 1 0 0 0;
                            0 1 0 0 0 0;
                            0 0 0 0 0 0;
                            0 0 0 0 0 0;
                            0 0 0 0 0 0]))
                    
    push!(features, vec(Int[0 0 0 1 1 1;
                            0 0 0 1 0 1;
                            0 0 0 1 1 1;
                            0 0 0 0 0 0;
                            0 0 0 0 0 0;
                            0 0 0 0 0 0]))
                    
    push!(features, vec(Int[0 0 0 0 0 0;
                            0 0 0 0 0 0;
                            0 0 0 0 0 0;
                            1 0 0 0 0 0;
                            1 1 0 0 0 0;
                            1 1 1 0 0 0]))
                    
    push!(features, vec(Int[0 0 0 0 0 0;
                            0 0 0 0 0 0;
                            0 0 0 0 0 0;
                            0 0 0 1 1 1;
                            0 0 0 0 1 0;
                            0 0 0 0 1 0]))
                    
    features = hcat(features...)

    return features
end


"""
    get_features_large()

Generate 35 12x12 features.
"""
function get_features_large()

    features = []

    push!(features, vec(Int[0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;

                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0]))

    push!(features, vec(Int[1 0 0 0 0 0  0 0 0 0 0 0;
                            1 0 0 0 0 0  0 0 0 0 0 0;
                            1 1 1 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;

                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0]))

    push!(features, vec(Int[0 1 1 0 0 0  0 0 0 0 0 0;
                            0 1 1 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;

                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0]))

    push!(features, vec(Int[0 0 0 0 1 0  0 0 0 0 0 0;
                            0 0 0 1 1 1  0 0 0 0 0 0;
                            0 0 0 0 1 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;

                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0]))

    push!(features, vec(Int[0 0 0 1 0 1  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 1 0 1  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;

                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0]))

    push!(features, vec(Int[0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            1 1 1 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;

                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0]))

    push!(features, vec(Int[0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            1 1 1 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;

                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0]))

    push!(features, vec(Int[0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            1 1 1 0 0 0  0 0 0 0 0 0;

                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0]))

    push!(features, vec(Int[0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 1 1 1  0 0 0 0 0 0;
                            0 0 0 0 1 1  0 0 0 0 0 0;
                            0 0 0 0 0 1  0 0 0 0 0 0;

                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0]))

    push!(features, vec(Int[0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 1 0 0  0 0 0 0 0 0;
                            0 0 0 1 1 0  0 0 0 0 0 0;

                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0]))

    push!(features, vec(Int[0 0 0 0 0 0  1 1 1 0 0 0;
                            0 0 0 0 0 0  1 1 0 0 0 0;
                            0 0 0 0 0 0  1 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;

                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0]))

    push!(features, vec(Int[0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 1 0 0 0;
                            0 0 0 0 0 0  0 1 1 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;

                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0]))

    push!(features, vec(Int[0 0 0 0 0 0  0 0 0 1 1 1;
                            0 0 0 0 0 0  0 0 0 1 0 1;
                            0 0 0 0 0 0  0 0 0 1 1 1;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;

                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0]))

    push!(features, vec(Int[0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 1 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;

                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0]))

    push!(features, vec(Int[0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 1 0 0;
                            0 0 0 0 0 0  0 0 0 1 1 1;
                            0 0 0 0 0 0  0 0 0 1 0 0;

                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0]))

    push!(features, vec(Int[0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 1 1;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;

                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0]))

    push!(features, vec(Int[0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 1 1;

                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0]))

    push!(features, vec(Int[0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 1 0 0 0;
                            0 0 0 0 0 0  1 1 1 0 0 0;
                            0 0 0 0 0 0  0 0 1 0 0 0;

                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0]))

    push!(features, vec(Int[0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  1 1 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  1 1 0 0 0 0;

                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0]))

    push!(features, vec(Int[0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;

                            0 1 0 0 0 0  0 0 0 0 0 0;
                            0 1 0 0 0 0  0 0 0 0 0 0;
                            1 1 1 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0]))

    push!(features, vec(Int[0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;

                            1 0 1 0 0 0  0 0 0 0 0 0;
                            1 0 1 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0]))

    push!(features, vec(Int[0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;

                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            1 1 1 0 0 0  0 0 0 0 0 0;
                            0 1 0 0 0 0  0 0 0 0 0 0;
                            0 1 0 0 0 0  0 0 0 0 0 0]))

    push!(features, vec(Int[0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;

                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            1 0 1 0 0 0  0 0 0 0 0 0;
                            1 0 1 0 0 0  0 0 0 0 0 0]))

    push!(features, vec(Int[0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;

                            0 0 0 1 0 0  0 0 0 0 0 0;
                            0 0 0 1 1 0  0 0 0 0 0 0;
                            0 0 0 1 1 1  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0]))

    push!(features, vec(Int[0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;

                            0 0 0 0 1 1  0 0 0 0 0 0;
                            0 0 0 0 0 1  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0]))

    push!(features, vec(Int[0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;

                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 1  0 0 0 0 0 0;
                            0 0 0 0 1 1  0 0 0 0 0 0;
                            0 0 0 1 1 1  0 0 0 0 0 0]))

    push!(features, vec(Int[0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;

                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 1 1 0  0 0 0 0 0 0;
                            0 0 0 1 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0]))

    push!(features, vec(Int[0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;

                            0 0 0 0 0 0  1 1 0 0 0 0;
                            0 0 0 0 0 0  1 1 0 0 0 0;
                            0 0 0 0 0 0  1 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0]))

    push!(features, vec(Int[0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;

                            0 0 0 0 0 0  0 0 1 0 0 0;
                            0 0 0 0 0 0  0 0 1 0 0 0;
                            0 0 0 0 0 0  0 1 1 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0]))

    push!(features, vec(Int[0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;

                            0 0 0 0 0 0  0 0 0 1 1 1;
                            0 0 0 0 0 0  0 0 0 0 0 1;
                            0 0 0 0 0 0  0 0 0 1 1 1;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0]))

    push!(features, vec(Int[0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;

                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 1 1 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0]))

    push!(features, vec(Int[0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;

                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  1 0 1 1 1 1;
                            0 0 0 0 0 0  1 0 1 0 0 1;
                            0 0 0 0 0 0  1 1 1 0 0 1]))


    push!(features, vec(Int[0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;

                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 1 1 0;
                            0 0 0 0 0 0  0 0 0 1 1 0]))

    push!(features, vec(Int[0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;

                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0;
                            0 0 0 0 0 0  0 1 0 0 0 0;
                            0 0 0 0 0 0  0 1 0 0 0 0;
                            0 0 0 0 0 0  0 0 0 0 0 0]))

    features = hcat(features...)
    return features[:,[1, 17, 16, 6, 22, 19, 11, 2, 28, 33, 4, 29, 31, 13, 27, 20, 18, 5, 9, 34, 23, 24, 25, 15, 21, 7, 32, 30, 12, 10, 8, 26, 14, 3]]
end